Struct embuild::build::LinkArgs[][src]

pub struct LinkArgs { /* fields omitted */ }

Implementations

Add the linker arguments from the native library.

Propagate all linker arguments to all dependents of this crate.

Important

Calling this method in a dependency doesn’t do anything on itself. All dependents that want to have these linker arguments propagated must call LinkArgs::output_propagated in their build script with the value of this crate’s links property (specified in Cargo.toml).

Add all linker arguments from lib_name which have been propagated using propagate.

lib_name doesn’t refer to a crate, library or package name, it refers to a dependency’s links property value, which is specified in its package manifest (Cargo.toml).