Struct embuild::cmake::Codemodel[][src]

pub struct Codemodel {
    pub version: Version,
    pub paths: Paths,
    pub configurations: Vec<Configuration>,
    // some fields omitted
}
The description of the build system structure as modeled by CMake.

Fields

version: Version

The version of this object kind.

paths: Paths

Some paths used by cmake.

configurations: Vec<Configuration>

All available build configurations.

On single-configuration generators there is one entry for the value of the CMAKE_BUILD_TYPE variable. For multi-configuration generators there is an entry for each configuration listed in the CMAKE_CONFIGURATION_TYPES variable.

Implementations

Turn this into configurations.

Turn this into configurations[0].

This functions panics if there are no configurations.

The path to the directory containing the file represented by this Codemodel instance.