Module git

Available on crate feature git only.
Git repository manipulation through the git CLI.

Modules

sdk

Structs

CloneOptions
Options for how a repository should be cloned by Repository::clone_ext.
Repository
A logical git repository which may or may not exist.

Enums

Ref
A reference to a git tag, branch or commit.
ResetMode
The mode passed to git reset HEAD --<mode>.

Constants

GIT
The git command.