Available on crate feature
git only.Expand description
Git repository manipulation through the git CLI.
Modules
Structs
- Clone
Options - Options for how a repository should be cloned by
Repository::clone_ext. - Repository
- A logical git repository which may or may not exist.
Enums
Constants
- GIT
- The git command.